@@ -7,8 +7,6 @@ import numpy as np
 class Model:
     TIME = 'time'
 
-    # TODO: Add check to make sure there's no unintentional override of variables while in the constructor.
-
     def __init__(self):
         super().__init__()
 
@@ -22,7 +20,7 @@ class Model:
         self._num_states = 0
         self._inputs = []
         self._parameters = []
-        self._vars = []
+        self._vars = set()
         self._models = []
         self._initial_values = {}
         self._current_state_values = {}
@@ -83,18 +81,27 @@ class Model:
         assert callable(def_formula), "def_formula must be callable."
         return lambda name: self._new_input(name, def_formula)
 
-    def _new_var(self, name, fun):
+    def _new_var(self, name, fun, override=False):
         assert self._under_construction, "Not under construction."
         assert callable(fun), "Fun must be callable."
         assert name.isidentifier(), "Name must be valid identifier."
-        assert not hasattr(self, name), "Name must not be already defined."
-        self._vars.append(name)
-        self._new_signal(name)
+        if not override:
+            assert not hasattr(self, name), "Name must not be already defined."
+            self._vars.add(name)
+            self._new_signal(name)
+        else:
+            assert hasattr(self, name), f"Name {name} must already defined if it's to be overridden."
+            assert name in self._vars, f"Name {name} must already defined if it's to be overridden."
+            assert name in self.signals, f"Name {name} must already defined if it's to be overridden."
         return self._get_signal_function(name, fun)
 
     def var(self, fun):
         assert self._under_construction, "Not under construction."
-        return lambda name: self._new_var(name, fun)
+        return lambda name: self._new_var(name, fun, override=False)
+
+    def ovar(self, fun):
+        assert self._under_construction, "Not under construction."
+        return lambda name: self._new_var(name, fun, override=True)
 
     def _new_parameter(self, name, val):
         assert name.isidentifier(), "Name must be valid identifier."
@@ -122,6 +129,12 @@ class Model:
         self._num_states = self.nstates()
         self._bypass_set_attr = False
 
+    def edit(self):
+        assert not self._under_construction, "Already under construction."
+        self._bypass_set_attr = True
+        self._under_construction = True
+        self._bypass_set_attr = False
+
     def set_time(self, t):
         """
         Sets the internal time, and all submodels's time, to t.
