@@ -19,23 +19,23 @@ class ModelSolver:
         # Record first time.
         model.record_state(x, start_t)
         sol = solve_ivp(f, (start_t, stop_t), x, method=StepRK45, max_step=h, model=model, t_eval=t_eval)
-        assert sol.success
+        if not sol.success:
+            raise ValueError(sol)
         if t_eval is not None:
             expected = len(t_eval)
-            model_signals = len(model.signals["time"])
             results_len = len(sol.y[0])
             assert expected == results_len, f"t_eval was ignored. Expected {expected} results. " \
-                                            f"Got {got} instead. " \
+                                            f"Got {results_len} instead. " \
                                             "This is a problem with scipy solver or you used the wrong type for t_eval."
+            model_signals = len(model.signals["time"])
             if not expected == model_signals:
-                self._l.info(f"Using f_eval implies that you don't rely on model.signals for error computation. "
-                                f"This is because model.signals contains {model_signals} points and t_eval contains {expected} points. "
-                                f"Use sol.y instead.")
+                self._l.info(f"The signals attribute is computed based on max_step and not based on t_eval. "
+                             f"Therefore model.signals contains {model_signals} points and t_eval contains {expected} points."
+                             f"Using t_eval implies that you rely on sol.y instead of the stored signals.")
 
         return sol
 
 
-
 class StepRK45(RK45):
 
     def __init__(self, fun, t0, y0, t_bound, max_step=np.inf,
@@ -49,7 +49,8 @@ class StepRK45(RK45):
 
     def step(self):
         msg = super().step()
-        assert msg is None, msg
+        if msg is not None:
+            raise ValueError(msg)
         step_taken = self.t - self._model.get_last_commit_time()
         if step_taken >= self.max_step:  # Improves performance by not recording every sample.
             self._model.record_state(self.y, self.t)
